# Rolo's Tools

## A collection of reusable python tools for use in Windows Environments

### Logger
Write to a log file in C:\windows\temp and also display in the console. 
Easily log plain strings, dated strings, and json objects

### Manip
Clean and manipulate different variable and data types

### Secure Env
securely store and retrieve environment variables

More details to come...